@@ -385,7 +385,7 @@ module_ibmpc (RECODE_OUTER outer)
   return true;
 }
 
-_GL_ATTRIBUTE_CONST void
+void
 delmodule_ibmpc (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
