@@ -177,7 +177,7 @@ module_latin1_bibtex (RECODE_OUTER outer)
     && declare_alias (outer, "btex", "BibTeX");
 }
 
-_GL_ATTRIBUTE_CONST void
+void
 delmodule_latin1_bibtex (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
